EiscatDIRAC
===========

.. image:: https://github.com/Eiscat3D/EiscatDIRAC/workflows/Basic%20tests/badge.svg
   :target: https://github.com/Eiscat3D/EiscatDIRAC/actions?query=workflow%3A%22Basic+tests%22+branch%3Amaster
   :alt: Basic Tests Status
   :align: right

`DIRAC <https://github.com/DIRACGrid/DIRAC>`_ extension for the Eiscat 3D Collaboration, see https://eiscat.se/.
